summaryrefslogtreecommitdiffstats
path: root/kdecore/kstdaccel.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdecore/kstdaccel.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/kstdaccel.h')
-rw-r--r--kdecore/kstdaccel.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdecore/kstdaccel.h b/kdecore/kstdaccel.h
index 9f379b210..008f71227 100644
--- a/kdecore/kstdaccel.h
+++ b/kdecore/kstdaccel.h
@@ -237,25 +237,25 @@ namespace KStdAccel
* Find, search. Default: Ctrl-f
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& find();
+ KDECORE_EXPORT const KShortcut& tqfind();
/**
* Find/search next. Default: F3
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& findNext();
+ KDECORE_EXPORT const KShortcut& tqfindNext();
/**
* Find/search previous. Default: Shift-F3
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& findPrev();
+ KDECORE_EXPORT const KShortcut& tqfindPrev();
/**
* Find and replace matches. Default: Ctrl-r
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& replace();
+ KDECORE_EXPORT const KShortcut& tqreplace();
/**
* Zoom in. Default: Ctrl-Plus
@@ -237,25 +237,25 @@ namespace KStdAccel
/**
- * Find and replace matches. Default: Ctrl-r
+ * Find and tqreplace matches. Default: Ctrl-r
* @return the shortcut of the standard accelerator
*/